function cx = CoexNetOneTailed(X, Y, alphanet, method, degDifSh, avgDegDifSh, alphatTest, flagPairing)

Xn = X(Y == -1, :);
Xd = X(Y == +1, :);

[cx.DegD, cx.AvgDegD] = calcDegNet(Xd, alphanet, method);
[cx.DegN, cx.AvgDegN] = calcDegNet(Xn, alphanet, method);

cx.DegDif = cx.DegD - cx.DegN;
cx.AvgDegDif = cx.AvgDegD - cx.AvgDegN;

[cx.pDc, cx.pAvgDeg] = calcDiffConn(cx.DegDif, degDifSh, cx.AvgDegDif, avgDegDifSh);
[cx.pDcPlus, cx.pAvgDegPlus] = calcDiffConnPlus(cx.DegDif, degDifSh, cx.AvgDegDif, avgDegDifSh);
[cx.pDcMinus, cx.pAvgDegMinus] = calcDiffConnMinus(cx.DegDif, degDifSh, cx.AvgDegDif, avgDegDifSh);
[cx.pDe,cx.statsDe] = calcDiffExpr(Xd, Xn, alphatTest, flagPairing);

% ------------------------------------------------------------------------
% nested functions
% ------------------------------------------------------------------------

    function [DegArray, AvgDeg] = calcDegNet(X, alphanet, method)
        
        switch method
            case 'Pearson'
                [~, P] = corrcoef(X);
            case 'Spearman'
                [~, P] = corr(X,'type','Spearman');
            otherwise
                error('Unexpected method: choose between Pearson and Spearman.');
        end
        
        A = single(P <= alphanet);
        
        [DegArray, AvgDeg] = calcGraphDegree(A);
    end

% ------------------------------------------------------------------------

    function [Deg, AvgD] = calcGraphDegree(A)
        % Note: ADJ must have zeros on main diagonal.
        Deg = zeros(size(A,2),1);
        for j = 1:size(A,2)
            Deg(j) = sum(A(j,:));
        end
        AvgD = (1/size(A,1))*sum(Deg);
    end

%-------------------------------------------------------------------------

    function [pvDc, pvDcAvg] =calcDiffConn(degDif, degDifSh, avgDegDif, avgDegDifSh)
        
        nShuffle = size(degDifSh,1);
        p = numel(degDif);
        pvDc = zeros(p,1);
        for j = 1:p
            if degDif(j) >= 0
                plus = degDifSh(:,j) > degDif(j);
                plus2 = degDifSh(:,j) < -degDif(j);
                pvDc(j) = (sum(plus)+sum(plus2))/nShuffle;
            else
                minus = degDifSh(:,j) < degDif(j);
                minus2 = degDifSh(:,j) > -degDif(j);
                pvDc(j) = (sum(minus)+sum(minus2))/nShuffle;
            end
        end
        
        if avgDegDif >= 0
            plusavg = avgDegDifSh > avgDegDif;
            plusavg2 = avgDegDifSh < -avgDegDif;
            pvDcAvg = (sum(plusavg)+sum(plusavg2))/nShuffle;
        else
            minusavg = avgDegDifSh < avgDegDif;
            minusavg2 = avgDegDifSh > -avgDegDif;
            pvDcAvg = (sum(minusavg) + sum(minusavg2))/nShuffle;
        end
        
    end

%-------------------------------------------------------------------------

    function [pvDcPlus, pvDcAvgPlus] =calcDiffConnPlus(degDif, degDifSh, avgDegDif, avgDegDifSh)
        
        nShuffle = size(degDifSh,1);
        p = numel(degDif);
        pvDcPlus = zeros(p,1);
        for j = 1:p
            plus = degDifSh(:,j) > degDif(j);
            pvDcPlus(j) = (sum(plus))/nShuffle;
            plusavg = avgDegDifSh > avgDegDif;
            pvDcAvgPlus = (sum(plusavg))/nShuffle;
        end
    end

%-------------------------------------------------------------------------

    function [pvDcMinus, pvDcAvgMinus] =calcDiffConnMinus(degDif, degDifSh, avgDegDif, avgDegDifSh)
        
        nShuffle = size(degDifSh,1);
        p = numel(degDif);
        pvDcMinus = zeros(p,1);
        for j = 1:p
            minus = degDifSh(:,j) < degDif(j);
            pvDcMinus(j) = (sum(minus))/nShuffle;
            minusavg = avgDegDifSh < avgDegDif;
            pvDcAvgMinus = (sum(minusavg))/nShuffle;
        end
    end

%-------------------------------------------------------------------------

    function [pvde,statsde] = calcDiffExpr(X1, X2, alphatTest, pairingTtest)
        %DIFFEXPRTEST
        %   Differential expression test
        if nargin < 3
            alphatTest = 0.05;
            pairingTtest = 'paired';
        end % Default alpha = 0.05
        
        switch pairingTtest
            case 'paired'
                %[~, pvde, ~, statsde] = ttest(X1, X2, 'Tail', 'right'); %paired t-test
                [~, pvde, ~, statsde] = ttest(X1, X2, alphatTest); %paired t-test
            case 'unpaired'
                [~, pvde, ~, statsde] = ttest2(X1, X2, alphatTest); %unpaired t-test
            otherwise
                error('Unexpected method: choose between paired or unpaired t-test.');
        end
        
    end

end