function [degDiffSh, avgDegDiffSh] = calcDegShuffle(X, Y, nShuffle, alphanet, method)

p = size(X,2);

degDiffSh = single(zeros(nShuffle, p));
avgDegDiffSh = single(zeros(nShuffle, 1));

pv1 = single(zeros(p, p));
pv2 = single(zeros(p, p));

parfor k = 1:nShuffle
    % Make an array of n integers (1:n), which are randomly permuted.
    N = numel(Y);
    M = sum(Y == -1);
    [Train, Test] = crossvalind('LeaveMOut', N, M);
    % Draw n/2 random rows of dataset to make ShuffleData1,
    % then use the remaining n/2 rows to make ShuffleData2.
    Shuffle1  = X(Train,:);
    Shuffle2  = X(Test,:);
    
    switch method
        case 'Pearson'
            % For each dataset, infer the adjacency matrix of the graph
            % by using Pearson correlation coefficients
            [~,pv1] = corrcoef(Shuffle1);
            [~,pv2] = corrcoef(Shuffle2);
        case 'Spearman'
            % For each dataset, infer the adjacency matrix of the graph
            % by using Pearson correlation coefficients
            
            [~,pv1] = corr(Shuffle1,'type','Spearman');
            [~,pv2] = corr(Shuffle2,'type','Spearman');
        otherwise
            error('Choose a method between Person and Spearman')
    end
    
    A1 = single(pv1 <= alphanet);
    A2 = single(pv2 <= alphanet);
    
    %Evaluate degree array for the two adjacency matrix.
    [degShuffle1, avgShuffle1] = calcGraphDegree(A1);
    [degShuffle2, avgShuffle2] = calcGraphDegree(A2);
    
    % Evaluate the matrix of the difference in which each row is
    % a permutation and each column corresponds to a gene.
    degDiffSh(k,:) = single((degShuffle1 - degShuffle2)');
    avgDegDiffSh(k) = single((avgShuffle1 - avgShuffle2)');
    
end

%--------------------------------

function [Deg, AvgD] = calcGraphDegree(A)

% Note: ADJ must have zeros on main diagonal.
Deg = zeros(size(A,2),1);

for j = 1:size(A,2)
    Deg(j) = sum(A(j,:));
end

AvgD = (1/size(A,1))*sum(Deg);