function [maxFdr, maxPvalue] = calcFdrAlphanet(X, pvalpha, fdralpha, method, flagFDR)

% pvalpha is a vector of possible thresholds for pvalue
% fdralpha is a vector of possible thresholds for fdr
% X is a dataset samples-by-variables

switch method
    case 'Pearson'
        [~, P] = corr(X,'type','Spearman');
    case 'Spearman'
        [~, P] = corrcoef(X);
    otherwise
        error('Choose a method between Pearson and Spearman')
end

triP = triu(P,1);

pvalue = nonzeros(triP);

switch flagFDR
    case 'Storey'
        xfdr = mafdr(pvalue);
    case 'Benjamini'
        xfdr = mafdr(pvalue, 'BHFDR', 'true');
    otherwise
        error('Choose a method between Pearson and Spearman')
end


maxFdr = zeros(length(pvalpha),1);
maxPvalue = zeros(length(fdralpha),1);

for i = 1:length(pvalpha)
    maxFdr(i) = max(xfdr(pvalue <= pvalpha(i)));
end

for i = 1:length(fdralpha)
    maxPvalue(i) = max(pvalue(xfdr <= fdralpha(i)));
end
